==> blobAndConquer-0.91-1.tar.gz: blobAndConquer-0.91/src/effects/decoration.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void addFireParticle(float x, float y, float z);
extern void addBloodParticle(float x, float y, float z);
extern void centerOnUnit(Unit *unit);
extern void addExplosionParticle(float x, float y, float z);
extern void drawBox(Vector position, float width, float length, float height);
extern bool withinViewableRange(Entity *entity);
extern Texture *getRequiredTexture(char *textureFileName);
extern SimpleModel *getRequiredSimpleModel(char *modelFileName, int type);
extern void moveEntity(Entity *entity);

extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern ModelManager *modelManager;
extern ParticleManager *particleManager;
extern TextureManager *textureManager;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/effects/decoration.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void addFireParticle(float x, float y, float z);
extern void addBloodParticle(float x, float y, float z);
extern void centerOnUnit(Unit *unit);
extern void addExplosionParticle(float x, float y, float z);
extern void drawBox(Vector position, float width, float length, float height);
extern bool withinViewableRange(Entity *entity);
extern Texture *getRequiredTexture(const char *textureFileName);
extern SimpleModel *getRequiredSimpleModel(const char *modelFileName, int type);
extern void moveEntity(Entity *entity);

extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern ModelManager *modelManager;
extern ParticleManager *particleManager;
extern TextureManager *textureManager;
